@@ -242,19 +242,17 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
         return resp.text
 
-    def update_aws_account(self, arn_role: str, external_id: str, name: str):
-        """ Register AWS
-        :param arn_role: IAM role ARN required for assume role to the customer cloud account
-        :param external_id: External ID required for assume role to the customer cloud account
-        :param name: Cloud account given name. If not passed its automatically generated by some pattern.
-        May be used only for CI, tests and developers environments. Should not be used in production"""
-
-        method_url = self._api_root.settings.aws_cloud_accounts()
-        request = {"name": name, "arn_role": arn_role, "external_id": external_id}
-
-        resp = self.session.put(url=method_url, json=request)
+    def get_k8s_cluster_agents(self, cluster_id: str):
+        method_url = self._api_root.agent_connector.get_k8s_cluster_agents(cluster_id=cluster_id)
+        resp = self.session.get(url=method_url)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
-        return resp
+        return resp.text
+
+    def rename_cloud_account(self, old_name: str, new_name: str):
+        method_url = self._api_root.settings.rename_cloud_accounts(old_name, new_name)
+
+        resp = self.session.put(url=method_url)
+        GatewayUtils.handle_response(resp, return_codes=[200])
 
     def get_account_template_url(self, external_id: str):
         """ Register AWS
@@ -503,7 +501,8 @@ class Colony:
                         duration: timedelta,
                         compute_availability: str,
                         lazy_load_artifacts: bool,
-                        lazy_load_artifacts_timeout: int
+                        lazy_load_artifacts_timeout: int,
+                        visibility: str
         """
         method_url = self._api_root.sandbox.sandboxes()
         request = {
@@ -515,6 +514,7 @@ class Colony:
             "compute_availability": kwargs.get("compute_availability"),
             "lazy_load_artifacts": kwargs.get("lazy_load_artifacts", False),
             "lazy_load_artifacts_timeout": kwargs.get("lazy_load_artifacts_timeout", 0),
+            "visibility": kwargs.get("visibility")
         }
 
         if kwargs.get("scheduled_end_time"):
@@ -1074,9 +1074,8 @@ class Colony:
         return [Converters.create_space_cloud_account_regions_response(region) for region in regions_json]
 
     def verify_cloud_account(self, cloud_account_name: str) -> VerifyCloudProviderResponse:
-        method_url = self._api_root.settings.verify_cloud_account()
-        data = {"cloud_account_name": cloud_account_name}
-        res = self.session.put(url=method_url, json=data)
+        method_url = self._api_root.settings.verify_cloud_account(cloud_account_name)
+        res = self.session.put(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
         verify_json = json.loads(res.text)
         return Converters.create_verify_response(verify_json)
