@@ -43,16 +43,11 @@ class BlueprintRepositoryDetails:
         self.branch = branch
 
 
-class BitbucketBlueprintRepositoryDetails(BlueprintRepositoryDetails):
-    def __init__(self, username: str, password: str, client_email: str, client_id: str, redirect_url: str,
-                 repository_url: str, repository_type: str, branch: str = None):
-        self.username = username
-        self.password = password
-        self.client_email = client_email
-        self.client_id = client_id
+class BitbucketBlueprintRepositoryDetails:
+    def __init__(self, auth_code: str, redirect_url: str, blueprint_repository_details: BlueprintRepositoryDetails):
+        self.blueprint_repository_details = blueprint_repository_details
+        self.auth_code = auth_code
         self.redirect_url = redirect_url
-        access_token = ''
-        super(BitbucketBlueprintRepositoryDetails, self).__init__(repository_url, access_token, repository_type, branch)
 
 
 class AddAccountBlueprintRepositoryRequest(abc.ABC):
