@@ -50,7 +50,8 @@ from gateways.common.cs18_api_responses import (
     K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse,
     AccountRepositoryDetailsBranchResponse, AccountRepositoryDetailsResponse,
     SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse, ParameterStoreItem,
-    ParameterStoreValue, ParameterStoreOrigin, LiteralValue, AwsSsmValue)
+    ParameterStoreValue, ParameterStoreOrigin, LiteralValue, AwsSsmValue, CloudRegionResponse,
+    CloudComputeServiceResponse)
 
 
 class Converters:
@@ -577,17 +578,28 @@ class Converters:
         )
 
     @staticmethod
-    def _create_cloud_response(service: dict) -> CloudResponse:
-        cloud_account_name = service.get("cloud_account_name")
-        region_id = ""
-        region_name = ""
-        if "region" in service:
-            region_id = service.get("region").get("id")
-            region_name = service.get("region").get("name")
+    def _create_cloud_region_response(region: dict) -> CloudRegionResponse:
+        if not region:
+            return CloudRegionResponse("", "")
+        return CloudRegionResponse(region_id=region.get("id"), region_name=region.get("name"))
+
+    @staticmethod
+    def _create_cloud_compute_service(compute_service: dict) -> CloudComputeServiceResponse:
+        return CloudComputeServiceResponse(
+            name=compute_service.get("name", None),
+            service_type=compute_service.get("type", None),
+            created_date=Converters._parse_datetime(compute_service.get("created_date", None)),
+            created_by=compute_service.get("created_by", None),
+            user_defined=compute_service.get("user_defined", None)
+        )
+
+    @staticmethod
+    def _create_cloud_response(cloud: dict) -> CloudResponse:
         return CloudResponse(
-            cloud_account_name=cloud_account_name,
-            region_id=region_id,
-            region_name=region_name
+            provider=cloud.get("provider"),
+            cloud_account_name=cloud.get("cloud_account_name"),
+            region=Converters._create_cloud_region_response(cloud.get("region")),
+            compute_service=Converters._create_cloud_compute_service(cloud.get("compute_service"))
         )
 
     @staticmethod
