@@ -292,15 +292,27 @@ class CloudRegionResponse:
         self.name = region_name
 
 
+class CloudComputeServiceResponse:
+    def __init__(self, name: str, service_type: str, created_date: datetime, created_by: str, user_defined: bool):
+        self.name = name
+        self.type = service_type
+        self.created_date = created_date
+        self.created_by = created_by
+        self.user_defined = user_defined
+
+
 class CloudResponse:
     def __init__(
             self,
+            provider: str,
             cloud_account_name: str,
-            region_id: str,
-            region_name: str = None
+            region: CloudRegionResponse,
+            compute_service: CloudComputeServiceResponse
     ):
+        self.provider = provider
         self.cloud_account_name = cloud_account_name
-        self.region = CloudRegionResponse(region_id=region_id, region_name=region_name)
+        self.region = region
+        self.compute_service = compute_service
 
 
 class ApplicationResponseBase:
