@@ -61,17 +61,6 @@ class TheGateway:
 
         GatewayUtils.handle_response(response=response, return_codes=[200])
 
-    def token_refresh_old(self, access_token: str, refresh_token: str) -> TokenResponse:
-        url = "{api_address}/api/token/refresh/{refresh_token}".format(
-            api_address=self.api_address, refresh_token=refresh_token
-        )
-        response = self._session.get(
-            url=url, headers=self._get_headers(access_token=access_token)
-        )
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-        token_json = json.loads(response.text)
-        return Converters.create_token_response(token_json)
-
     def token_refresh(self, access_token: str, refresh_token: str) -> TokenResponse:
         url = "{api_address}/api/token/refresh".format(
             api_address=self.api_address
